==> huaweicloudsdkeip-3.1.108-py2.py3-none-any.whl: huaweicloudsdkeip/v2/model/list_publicips_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListPublicipsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'publicips': 'list[PublicipShowResp]'
    }

    attribute_map = {
        'publicips': 'publicips'
    }

    def __init__(self, publicips=None):
        """ListPublicipsResponse

        The model defined in huaweicloud sdk

        :param publicips: 弹性公网IP对象
        :type publicips: list[:class:`huaweicloudsdkeip.v2.PublicipShowResp`]
        """
        
        super(ListPublicipsResponse, self).__init__()

        self._publicips = None
        self.discriminator = None

        if publicips is not None:
            self.publicips = publicips

    @property
    def publicips(self):
        """Gets the publicips of this ListPublicipsResponse.

        弹性公网IP对象

        :return: The publicips of this ListPublicipsResponse.
        :rtype: list[:class:`huaweicloudsdkeip.v2.PublicipShowResp`]
        """
        return self._publicips

    @publicips.setter
    def publicips(self, publicips):
        """Sets the publicips of this ListPublicipsResponse.

        弹性公网IP对象

        :param publicips: The publicips of this ListPublicipsResponse.
        :type publicips: list[:class:`huaweicloudsdkeip.v2.PublicipShowResp`]
        """
        self._publicips = publicips

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListPublicipsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkeip-3.1.148-py2.py3-none-any.whl: huaweicloudsdkeip/v2/model/list_publicips_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListPublicipsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'publicips': 'list[PublicipShowResp]'
    }

    attribute_map = {
        'publicips': 'publicips'
    }

    def __init__(self, publicips=None):
        r"""ListPublicipsResponse

        The model defined in huaweicloud sdk

        :param publicips: 弹性公网IP对象
        :type publicips: list[:class:`huaweicloudsdkeip.v2.PublicipShowResp`]
        """
        
        super(ListPublicipsResponse, self).__init__()

        self._publicips = None
        self.discriminator = None

        if publicips is not None:
            self.publicips = publicips

    @property
    def publicips(self):
        r"""Gets the publicips of this ListPublicipsResponse.

        弹性公网IP对象

        :return: The publicips of this ListPublicipsResponse.
        :rtype: list[:class:`huaweicloudsdkeip.v2.PublicipShowResp`]
        """
        return self._publicips

    @publicips.setter
    def publicips(self, publicips):
        r"""Sets the publicips of this ListPublicipsResponse.

        弹性公网IP对象

        :param publicips: The publicips of this ListPublicipsResponse.
        :type publicips: list[:class:`huaweicloudsdkeip.v2.PublicipShowResp`]
        """
        self._publicips = publicips

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListPublicipsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
